==> mcmcplots_0.1.tar.gz: mcmcplots/man/traplot.Rd <==
\name{traplot}
\alias{traplot}
\title{ Traceplots of Multiple Parameters. }

\description{
  This function produces trace plots from an MCMC simulation on a single plot for all parameters (by default) or those parameters indicated by the \code{parms} argument.
}

\usage{
traplot(mcmcout, parms = NULL, regex = NULL, random = NULL, ylim = NULL, auto.layout = TRUE, mar=c(2.0, 2.0, 1.5, 0.25)+0.1, col = mcmcplotsPalette(nchains), lty = 1, main = NULL, \dots)
}

\arguments{
  \item{mcmcout}{ an object that can be coerced to an \code{mcmc} or \code{mcmc.list} object  }
  \item{parms}{ character vector specifying which subsets of parameters to plot.  If \code{NULL}, \code{mcmcplot} will plot all parameters. Regular expressions are used to strip all numbers and punctuation out of the parameter names to find the parameters that match the character strings in \code{parms}.}
  \item{regex}{ character vector of regular expressions denoting groups of parameters to plot.}
  \item{random}{ an integer indicating the maximum number of parameters to randomly select for plotting from each group of parameters as specified by the \code{parms} argument. }
  \item{ylim}{ limits for the y-axis.}
  \item{auto.layout}{automatically creates a plot layout using \code{mult.fig} if \code{TRUE}.}
  \item{mar}{ argument passed to \code{multi.fig} if \code{auto.layout=TRUE}}
  \item{col}{colors to be used in plotting the densities.}
  \item{lty}{line types to be used in plotting.}
  \item{main}{ main title for the plots. Default is to use parameter names.}
  \item{\ldots}{ further arguments passed to the plotting function. }
}

\details{
  None.
}

\value{
  Creates a plot.
}

\references{
  None.
}

\author{ S. McKay Curtis }

\note{
  None.
}

\seealso{
  \code{\link{denplot}}
}

\examples{
## Create fake MCMC output
nc <- 10; nr <- 1000
pnames <- c(paste("alpha[", 1:5, "]", sep=""), paste("gamma[", 1:5, "]", sep=""))
means <- rpois(10, 20)
fakemcmc <- as.mcmc.list(lapply(1:3, function(i) mcmc(matrix(rnorm(nc*nr, rep(means,each=nr)), nrow=nr, dimnames=list(NULL,pnames)))))

## Plot traces of the fake MCMC output
traplot(fakemcmc)
traplot(fakemcmc, style="plain")
traplot(fakemcmc, "gamma")

\dontrun{
## traplot works on bugs objects too
library(R2WinBUGS)
example("openbugs", "R2WinBUGS")
## from the help file for openbugs:
schools.sim <- bugs(data, inits, parameters, model.file,
                    n.chains = 3, n.iter = 5000,
                    program = "openbugs", working.directory = NULL)
traplot(schools.sim, "theta")
}

}

\keyword{ hplot }

==> mcmcplots_0.2.tar.gz: mcmcplots/man/traplot.Rd <==
\name{traplot}
\alias{traplot}
\title{ Traceplots of Multiple Parameters. }

\description{
  This function produces trace plots from an MCMC simulation on a single plot for all parameters (by default) or those parameters indicated by the \code{parms} argument.
}

\usage{
traplot(mcmcout, parms = NULL, regex = NULL, random = NULL, ylim = NULL,
auto.layout = TRUE, mar=c(2.0, 2.0, 1.5, 0.25)+0.1, col =
mcmcplotsPalette(nchains), lty = 1, main = NULL, style = c("gray", "plain"), \dots)
}

\arguments{
  \item{mcmcout}{ an object that can be coerced to an \code{mcmc} or \code{mcmc.list} object  }
  \item{parms}{ character vector specifying which subsets of parameters to plot.  If \code{NULL}, \code{mcmcplot} will plot all parameters. Regular expressions are used to strip all numbers and punctuation out of the parameter names to find the parameters that match the character strings in \code{parms}.}
  \item{regex}{ character vector of regular expressions denoting groups of parameters to plot.}
  \item{random}{ an integer indicating the maximum number of parameters to randomly select for plotting from each group of parameters as specified by the \code{parms} argument. }
  \item{ylim}{ limits for the y-axis.}
  \item{auto.layout}{automatically creates a plot layout using \code{mult.fig} if \code{TRUE}.}
  \item{mar}{ argument passed to \code{multi.fig} if \code{auto.layout=TRUE}}
  \item{col}{colors to be used in plotting the densities.}
  \item{lty}{line types to be used in plotting.}
  \item{main}{ main title for the plots. Default is to use parameter names.}
  \item{style}{ if "gray", then the plotting region is printed with a gray background, otherwise the default plotting region is used.}
  \item{\ldots}{ further arguments passed to the plotting function. }
}

\details{
  None.
}

\value{
  Creates a plot.
}

\references{
  None.
}

\author{ S. McKay Curtis }

\note{
  None.
}

\seealso{
  \code{\link{denplot}}
}

\examples{
## Create fake MCMC output
nc <- 10; nr <- 1000
pnames <- c(paste("alpha[", 1:5, "]", sep=""), paste("gamma[", 1:5, "]", sep=""))
means <- rpois(10, 20)
fakemcmc <- as.mcmc.list(lapply(1:3, function(i) mcmc(matrix(rnorm(nc*nr, rep(means,each=nr)), nrow=nr, dimnames=list(NULL,pnames)))))

## Plot traces of the fake MCMC output
traplot(fakemcmc)
traplot(fakemcmc, style="plain")
traplot(fakemcmc, "gamma")

\dontrun{
## traplot works on bugs objects too
library(R2WinBUGS)
example("openbugs", "R2WinBUGS")
## from the help file for openbugs:
schools.sim <- bugs(data, inits, parameters, model.file,
                    n.chains = 3, n.iter = 5000,
                    program = "openbugs", working.directory = NULL)
traplot(schools.sim, "theta")
}

}

\keyword{ hplot }
